# spdcalc-py

[![Documentation](https://img.shields.io/badge/spdcalc-blue?style=flat-square&logo=readthedocs&logoColor=white)](https://spdcalc-py.readthedocs.io)
[![PyPI](https://img.shields.io/pypi/v/spdcalc-py.svg?logo=python&style=flat-square)](https://pypi.org/project/spdcalc-py)

Python bindings for spdcalc

## Getting Started

See the [Quickstart](docs/source/quickstart.md) guide for a quick introduction to using spdcalc-py.
